#
# spec file for package mtools
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mtools
Version:        4.0.35
Release:        150400.1.11
Summary:        Tools to access MS-DOS filesystems without kernel drivers
License:        GPL-3.0-or-later
Group:          System/Filesystems
URL:            http://mtools.linux.lu/
Source0:        https://ftp.gnu.org/gnu/mtools/%{name}-%{version}.tar.bz2
Source1:        https://ftp.gnu.org/gnu/mtools/%{name}-%{version}.tar.bz2.sig
# https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=mtools
Source2:        %{name}.keyring
Patch0:         %{name}-conf.diff
Patch3:         %{name}-aliasing.diff
Patch5:         %{name}-prototypes.diff
BuildRequires:  makeinfo
BuildRequires:  texinfo
Requires:       glibc-locale-base

%description
Mtools allows access to an MS-DOS file system on disk without
mounting it. It includes commands for working with MS-DOS files:
mdir, mcd, mcopy, and mformat.

XDF support for OS/2 is also provided.

%package doc
Summary:        Documentation for mtools, a toolset for MS-DOS filesystem access
License:        GFDL-1.3-only AND GPL-3.0-or-later
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc
Mtools allows access to an MS-DOS file system on disk without
mounting it. This subpackage contains the documentation for it.

%prep
%setup -q
%patch0
%patch3
%patch5 -p1

%build
%configure \
	--includedir=%{_prefix}/src/linux/include \
	--disable-floppyd

%make_build -j1 all info pdf

%install
install -d -m 755 %{buildroot}%{_sysconfdir}
make DESTDIR=%{buildroot} install --jobs 1
cp -p mtools.conf %{buildroot}%{_sysconfdir}

%files
%config %{_sysconfdir}/mtools.conf
%doc Release.notes NEWS README*
%license COPYING
%{_mandir}/man?*/*
%exclude %{_mandir}/man?*/f*
%{_infodir}/mtools.info%{?ext_info}
%{_bindir}/*
%exclude %{_bindir}/f*

%files doc
%license COPYING
%doc *.pdf

%changelog
* Sat Aug  7 2021 andreas.stieger@gmx.de
- mtools 4.0.35:
  * Fix cluster padding at end of file in batch mode
* Sat Jul 24 2021 andreas.stieger@gmx.de
- mtools 4.0.34:
  * Fix mcopy -s issue
- includes changes from 4.0.33:
  * Fix support for partitions
  * Add support for image files on command line to mcat
- includes changes from 4.0.32:
  * Simplify algorithm that choses filesystem parameters for
    format, and align it more closely with what Win7 does
  * Fix mformatting XDF when XDF not explicitly specified on
    mformat command line
  * easier way to enter sizes on mformat command line
    (mformat -C -T 1440K)
  * For small sizes, mformat assumes floppy geometries
    (heads 1 or 2, tracks 40 or 80)
  * Handle attempts to mformat too small filesystems more
    gracefully
  * Enable minfo to print out additional mformat command line
    parameters, if the present filesystem uses non-default
    values for these
  * minfo no longer prints bigsect if smallsect is set
  * for remap filter, error when trying to write non-zero data
    to unmapped sectors
- drop mtools-autoconf.diff, no longer needed
- drop mtools-fat-bits.diff, drop candidate for some time
* Sun Jun 20 2021 andreas.stieger@gmx.de
- mtools 4.0.31:
  * Fix polarity of format_xdf command-line parameter of mformat
  * Improved error handling and error messages
  * Remove duplicate writing of backup boot sector
  * developer visible changes
- includes changes from 4.0.30:
  * Fixed XDF floppy disk access
  * Fixed faulty behavior at end of image in mcat
  * Raise an error when trying to mcopy multiple source files
    over a single destination file (rather than directory)
  * fix handling of "hidden" sectors
  * Modernize partition support
  * developer visible changes
- includes changes from 4.0.29 and 4.0.28:
  * Support remapping of data
  * Re-open floppy devices read-write if geometry parameters need
    to be changed
  * relax consistency checks in mpartition (partitions created
    by current fdisk would almost never pass these checks)
* Sun Apr 18 2021 andreas.stieger@gmx.de
- mtools 4.0.27:
  * Fix type error in calls to iconv functions
* Sun Nov 29 2020 andreas.stieger@gmx.de
- mtools 4.0.26:
  * Ignore image file locking errors if we are performing a read-
    only access anyways
- remove obsolete texinfo packaging macros, update signing keyring
* Sun Oct 25 2020 andreas.stieger@gmx.de
- mtools 4.0.25:
  * Preserve non-updated contents of info sector, just in case
    it contains program code
  * When parsing config file, always use "C" locale for
    case-insensitive comparisons
* Sat Mar 28 2020 andreas.stieger@gmx.de
- mtools 4.0.24:
  * Added AC_SYS_LARGEFILE for some ARM processors
* Wed Mar 18 2020 pgajdos@suse.com
- require glibc-locale-base instead o glibc-locale [bsc#1165837]
  [bsc#957007]
* Fri Dec 28 2018 pgajdos@suse.com
- mtools 4.0.23:
  * Address lots of compiler warnings (assignments between different types)
  * Network speedup fixes for floppyd (TCP_CORK)
  * Typo fixes
  * Explicitly pass available target buffer size for character
  set conversions
- refreshed:
  %% mtools-prototypes.diff
* Tue Dec 11 2018 jengelh@inai.de
- Use noun phrase in summary.
- Fix excessively large keyring.
* Fri Dec  7 2018 malte.kraus@suse.com
- mtools 4.0.22:
  * Fixed -f flag for mformat (size is KBytes, rather than sectors)
  * Fixed toupper/tolower usage (unsigned char rather than plain
    signed)
- mtools 4.0.21:
  * Addressed compiler warnings
  * Fixed length handling in character set conversion (Unicode file
    names)
  * Fixed matching of character range, when containing Unicode
    characters (mdir "c:test[α-ω].exe")
  * Fixed initialization of my_scsi_cmd constructor
* Wed Nov 14 2018 mloviska@suse.com
- Update to 4.0.20:
  * initialize directory entries to 0
  * bad message "Too few sectors" replaced with "Too many sectors"
  * apostrophe in mlabel no longer causes generation of long entry
  * option to fake system date for file creation using the
  SOURCE_DATE_EPOCH environment variables
  * can now be compiled with "clang" compiler
  * fallback function for strndup, for those platforms that don't have it
  * fixed a number of -Wextra warnings
  * new compressed archive formats for uz/lz
  * allow to specify number of reserved sectors for FAT32.
  * file/device locking with timeout (rather than immediate failure)
  * fixed support for BPB-less legacy formats.
  * removed check that disk must be an integer number of tracks.
  * removed .eh/.oh macros from manual pages
* Wed Oct 31 2018 pgajdos@suse.com
- patches unversioned; makes update and reviews easier
  * mtools-4.0.18-fat-bits.diff -> mtools-fat-bits.diff
  * mtools-4.0.18-conf.diff -> mtools-conf.diff
  * mtools-4.0.18-aliasing.diff -> mtools-aliasing.diff
  * mtools-4.0.18-prototypes.diff -> mtools-prototypes.diff
  * mtools-4.0.18-autoconf.diff -> mtools-autoconf.diff
* Sat Oct 27 2018 sean@suspend.net
- Update to 4.0.19:
  * Fix for short file names starting with character 0xE5
  * mpartition: Partition types closer to what Microsoft uses
  * mformat: figure out LBA geometry as last resort if geometry is unspecified
  * mformat: use same default cluster size as Microsoft for FAT32
  * additional sanity checks
  * document how clutser size is picked in mformat.c man page
  * document how partition types are picked in mpartition.c man page
* Mon Jul 16 2018 pgajdos@suse.com
- do not build in parallel as it fails
* Fri Apr 27 2018 stefan.bruens@rwth-aachen.de
- Disable floppyd support. Floppyd is a daemon allowing remote X
  clients to access floppies attached to e.g. thin clients. As it
  uses X authentication, it pulls in X libraries.
* Tue Feb 13 2018 crrodriguez@opensuse.org
- Do not BuildRequire metapackage xorg-x11-devel
* Mon Nov 30 2015 pgajdos@suse.com
- require glibc-locale [bnc#957007]
* Thu Feb 26 2015 mpluskal@suse.com
- Clean spec file with spec-cleaner
- Refresh dependencies
- Add gpg signature
* Tue Apr 16 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Mar 26 2013 pgajdos@suse.com
- updated to 4.0.18:
  * Fix for names of iconv encodings on AIX
  * Fix mt_size_t on NetBSD
  * Fixed compilation on Mingw
  * Fixed doc (especially mformat)
  * Fix mformat'ing of FAT12 filesystems with huge cluster sizes
  * Minfo prints image file name in mformat command line if an image
    file name was given
  * Always generate gzip-compressed RPMs, in order to remain
    compatible with older distributions
  * Fixed buffer overflow with drive letter in mclasserase
- extended fat-bits.patch: add fat_bits parameter again to fat_read()
  and old_fat_read(); it is candidate to drop though
* Tue Jul 24 2012 werner@suse.de
- Make it build with texinfo/makeinfo split
* Mon Jul 23 2012 coolo@suse.com
- add texinfo as buildrequire
* Mon Jul  2 2012 cfarrell@suse.com
- license update: GPL-3.0+
  mtools is GPL-3.0+ licensed, not GPL-2.0+
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Thu Jun 30 2011 pgajdos@novell.com
- updated to 4.0.17:
  * mbadblocks now takes a list of bad blocks (either as sectors
    or as clusters)
  * mbadblocks now is able to do write scanning for bad blocks
  * mshowfat can show cluster of specific offset
  * Enable mtools to deal with very small sector sizes...
  * Fixed encoding of all-lowercase names (no need to mangle
    these)
  * Consider every directory entry after an ENDMARK (0x00) to be deleted
  * After writing a new entry at end of a directory, be sure to also add
    an ENDMARK (0x00)
  * Deal with possibility of a NULL pointer being returned by
    localtime during timestamp conversion
* Mon May 23 2011 pgajdos@novell.com
- updated to 4.0.16:
  * fixed formatting of fat_size_calculation.tex document
  * Make it clear that label is limited to 13 characters
  * Fixed typo in initialization of FAT32 info sector
- remove invalid-memory.diff
* Thu Mar 17 2011 pgajdos@suse.cz
- fixed crash caused with access of invalid memory [bnc#679459]
* Tue Nov 16 2010 pgajdos@suse.cz
- updated to version 4.0.15:
  * Added missing -i option to mshortname
  * New mshortname command
  * Fix floppyd for disks bigger than 2 Gig
  * Remove obsolete -z flag
  * Remove now unsupported AC_USE_SYSTEM_EXTENSIONS
  * Fixed output formatting of mdir if MTOOLS_DOTTED_DIR is set
  * Mformat now correctly writes backup boot sector
  * Fixed signedness of serial number in mlabel
  * Fixed buffer size problem in mlabel
  * Make mlabel write backup boot sector if FAT32
  * Catch situation where both clear and new label are given to mlabel
  * Quote filename parameters to scripts
  * Mformat: Close file descriptor for boot sector
  * Added lzip support to scripts/uz
  * Added Tot_sectors option to mformat
  * Fixed hidden sector handling in mformat
  * Minfo generates mformat command lines containing new -T option
  * Mlabel prints error if label too long
- removed upstreamed patches:
  * script.diff
  * file_close.diff
  * initialize.diff
* Tue Jun 29 2010 pgajdos@suse.cz
- fixed initialization in mlabel.c [bnc#618326]
* Mon Mar  1 2010 pgajdos@suse.cz
- updated to 4.0.13 (upstreamed debian patches)
* Sun Dec  6 2009 meissner@suse.de
- uppercase summary of -floppyd
* Tue Nov 24 2009 pgajdos@suse.cz
- updated to 4.0.12 (see NEWS)
  - removed upstreamed help-flag.diff and overflow.diff
* Fri Oct 23 2009 pgajdos@suse.cz
- fixed wrong -h flag [bnc#548449]
  * help-flag.diff
* Tue Sep 15 2009 pgajdos@suse.cz
- added missing call to close [bnc#535718]
* Wed Apr 15 2009 ro@suse.de
- buildfix: refresh patches
* Mon Mar 16 2009 pgajdos@suse.cz
- updated to 4.0.10 (see NEWS)
  * adjusted overflow.patch
- splitted out doc package
* Wed Jan 21 2009 schwab@suse.de
- Fix buffer overflows.
* Tue Jan 13 2009 pgajdos@suse.cz
- updated to 4.0.1
  * unicode support
  * use transliteration to represent characters which don't exist in
    target set
  * Offset for -i-specified image files
* Tue Jun  5 2007 prusnak@suse.cz
- updated to 3.9.11
  * fixed reading of boot sector
  * fixed mlabel on read-only disks
  * added sizecode printing on minfo
  * support for config parameters after -i file
- drop obsolete patches:
  * memset.diff (included in update)
* Sun Apr 22 2007 ro@suse.de
- use texlive for building
* Mon Feb  6 2006 mjancar@suse.cz
- bransh mtools-floppy to prevent dependecy on X11 (#146102)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 18 2005 meissner@suse.de
- fixed swapped memset() arguments.
* Wed Aug  3 2005 mjancar@suse.cz
- update to 3.9.10
- drop obsolete patches:
  * mtools-3.9.9-20030718.diff.gz
  * mtools-execNULL.diff
- split mtools-3.9.9.diff into:
  * mtools-3.9.10-autoconf.diff
  * mtools-3.9.10-conf.diff
  * mtools-3.9.10-prototypes.diff
* Tue Apr  5 2005 mmj@suse.de
- execl(..., 0) --> execl(..., NULL);
* Sun Feb 13 2005 ro@suse.de
- added libpng to nfb (for tetex)
* Mon Jan 24 2005 meissner@suse.de
- fixed one execl call, fixed one lvalue cast.
* Sun Jun 13 2004 schwab@suse.de
- Allow overriding fat bits.
* Thu Apr 22 2004 tcrhak@suse.cz
- strict aliasing fix
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Jul 31 2003 uli@suse.de
- fixed to build on 64-bit archs
* Tue Jul 29 2003 tcrhak@suse.cz
- update to version 3.9.9
* Thu Dec 19 2002 tcrhak@suse.cz
- updated patch to mtools-3.9.8-20021118.diff.bz2
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Dec  3 2001 tcrhak@suse.cz
- updated patch to mtools-3.9.8-20011127.diff.bz2
* Mon Oct  1 2001 schwab@suse.de
- Fix quoting in shell scripts.
* Wed Jun 13 2001 adostal@suse.cz
- upgrade to 3.9.8
* Tue Jun 12 2001 schwab@suse.de
- Fix configure script.
* Tue Apr  3 2001 cihlar@suse.cz
- updated patchkit
* Mon Mar 26 2001 cihlar@suse.cz
- updated patchkit
* Fri Feb  9 2001 cihlar@suse.cz
- removed lx_suse from neededforbuild
- do not include kernel headers
* Thu Feb  8 2001 cihlar@suse.cz
- fixed to compile
* Tue Jan  9 2001 cihlar@suse.cz
- updated patchkit
* Tue Dec  5 2000 cihlar@suse.cz
- updated patchkit
* Wed Nov 22 2000 cihlar@suse.cz
- updated patchkit
* Thu Nov  9 2000 cihlar@suse.cz
- improved BuildRoot
- fixed file list
- bzipped sources
* Fri Oct 20 2000 cihlar@suse.cz
- updated patchkit
* Fri Sep  8 2000 schwab@suse.de
- Fix typo in configure script and pass -D_GNU_SOURCE to compiler
  (obsoletes last change for alpha)
- Add suse_update_config.
* Mon Aug 28 2000 ro@suse.de
- fixed to compile on alpha
* Wed Aug 16 2000 cihlar@suse.cz
- updated patchkit
* Sat Jun 24 2000 kasal@suse.de
- updated patchkit
* Mon Jun 19 2000 kasal@suse.de
- upgrade to 3.9.7
* Wed Apr 26 2000 kasal@suse.de
- upgrade to mtools-3.9.6-20000417.diff.gz
* Wed Apr 12 2000 kasal@suse.cz
- upgrade to mtools-3.9.6-20000410.diff.gz
* Mon Mar 27 2000 kasal@suse.cz
- added patch mtools-3.9.6-20000320b.diff.gz (fixes BUG# 2590)
* Wed Mar  1 2000 kasal@suse.de
- moved manpages to %%{_mandir}
- added buildroot and shortened %%filelist
- added mtools.info* files (and texinfo to #neededforbuild)
* Mon Sep 20 1999 uli@suse.de
- fixed #include conflict showing up on PPC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jul  9 1999 uli@suse.de
- update -> 3.9.6
* Tue Mar 23 1999 ro@suse.de
- don't use -O4 ; strip binaries
* Mon Mar 22 1999 ro@suse.de
- update to 3.9.4
* Fri Dec 11 1998 rj@suse.de
- parameters in mtools.conf for 1,44MB disks hardcoded
* Wed Oct 28 1998 ro@suse.de
- respect change in 2.1.126 SCSI_DISK_MAJOR
* Sun Jul 26 1998 bs@suse.de
- used old config file again.
* Tue Jul 21 1998 bs@suse.de
- update to version 3.9.1
* Tue Feb 24 1998 ro@suse.de
- removed man-pages mread and mwrite
  (contain no information, just texinfos blabla)
* Thu Jun 12 1997 rj@suse.de
- modification in /etc/mtools.conf
* Fri Apr 18 1997 rj@suse.de
- new version 3.6
* Mon Mar  3 1997 rj@suse.de
- new version 3.3
* Tue Feb 25 1997 rj@suse.de
- new version 3.2
  - /usr/doc/packages/mtools now included
  - xdf Support
